@@ -6,8 +6,8 @@ function(
 	, within = NULL
 	, between = NULL
 	, perms
+	, alarm = TRUE
 ){
-	start = proc.time()[3]
 	if(is.null(within) & is.null(between)){
 		stop('is.null(within) & is.null(between)\nYou must specify at least one independent variable.')
 	}
@@ -46,7 +46,7 @@ function(
 	}
 	data=data[,names(data) %in% c(within,between,wid,dv)]
 	cat('Permutation test progress:\n')
-	start = proc.time()[1]
+	start = proc.time()[3]
 	aov_formula = paste(
 		as.character(dv)
 		,'~'
@@ -84,7 +84,8 @@ function(
 			}
 		)
 	}
-	pb = txtProgressBar(max=perms,style=3)
+	progress = create_progress_bar('time')
+	progress$init(perms)
 	for(this_perm in 1:perms){
 		for(this_within in within){
 			sim_data = ddply(
@@ -103,8 +104,33 @@ function(
 			}
 		}
 		sim[,this_perm] = ezPerm_aov(sim_data,aov_formula)
-		setTxtProgressBar(pb, this_perm)
+		progress$step()
 	}
+	progress$term()
+	#sim = ldply(
+	#	.data = 1:perms
+	#	, .fun = function(x){
+	#		for(this_within in within){
+	#			sim_data = ddply(
+	#				sim_data
+	#				,.variables = structure(as.list(c(wid,structure(within[within!=this_within],class='quoted'))),class='quoted')
+	#				,function(x){
+	#					x[,names(x)==this_within] = sample(x[,names(x)==this_within])
+	#					return(x)
+	#				}
+	#			)
+	#		}
+	#		for(this_between in between){
+	#			group_info[,names(group_info)==this_between]=sample(group_info[,names(group_info)==this_between])
+	#			for(this_wid in sim_data[,names(sim_data)==wid]){
+	#				sim_data[sim_data[,names(sim_data)==wid]==this_wid,names(sim_data)==this_between] = group_info[group_info[,names(group_info)==wid]==this_wid,names(group_info)==this_between]
+	#			}
+	#		}
+	#		return(ezPerm_aov(sim_data,aov_formula))
+	#	}
+	#	, .progress = 'time'
+	#	, .parallel = TRUE
+	#)
 	Effect = ezANOVA_main(data,dv,wid,within,between,observed=NULL,diff=NULL,reverse_diff=FALSE)$ANOVA$Effect
 	if(is.null(between)){
 		Effect = Effect[2:length(Effect)]
@@ -112,8 +138,8 @@ function(
 	perm_test = data.frame(Effect=Effect)
 	perm_test$p = rowMeans(sim>=obs)
 	perm_test$'p<.05' = ifelse(perm_test$p<.05,'*','')
-	close(pb)
-	cat('Time taken for ezPerm() to complete:',round(proc.time()[3]-start),'seconds')
-	return(list('Permutation Test'=perm_test,'Test Duration' = as.vector(proc.time()[1] - start)))
+	cat('Time taken for ezPerm() to complete:',round(proc.time()[3]-start),'seconds.\n')
+	alarm()
+	return(list('Permutation Test'=perm_test,'Test Duration' = as.vector(proc.time()[3] - start)))
 }
 
